(v1.2.0)=
### 1.2.0 {small}`2018-06-08`

- {func}`~scanpy.tl.paga` improved, see [PAGA](https://github.com/theislab/paga); the default model changed, restore the previous default model by passing `model='v1.0'`
